@@ -24,7 +24,7 @@ Typical usage example:
 import math
 import tarfile
 from enum import Enum
-from typing import Tuple, Dict, List
+from typing import Tuple, Dict, List, Optional
 
 import requests
 import os
@@ -52,12 +52,17 @@ class IExample:
     This only defines methods and properties related to data access.
     """
 
-    def __init__(self, data_dir=None):
+    def __init__(self, data_dir: Optional[str] = None):
         """Construct an instance of the Example class."""
 
         # Will eventually hold the waveform data from the event
+        #: (pd.DataFrame): The DataFrame for holding the actual waveform data
         self.event_df = None
+
+        #: (str): The directory where the waveform data can be found.  None if Config is to be referenced.
         self.data_dir = data_dir
+
+        #: (ExampleType): The type of example this is.
         self.e_type = None
 
     def load_data(self) -> None:
@@ -95,7 +100,10 @@ class Factory:
                 All additional keyword arguments will be passed to the responsible constructor on every get_example()
                 call.
         """
+        #: (ExampleType): The type of example that is to be made.
         self.e_type = e_type
+
+        #: (dict of str:Any): kwargs to be passed to example constructor
         self.example_kwargs = kwargs
 
     def get_example(self, e_type: ExampleType = None, **kwargs) -> IExample:
@@ -153,34 +161,44 @@ class Example(IExample):
     fault_label: a string label specifying the type of fault that occurred (ExampleSet has a list of "known" labels")
     cavity_conf: A floating point number in [0, 1] representing the probability/confidence placed in the cavity label
     fault_conf: A floating point number in [0, 1] representing the probability/confidence placed in the fault label
-    label_source: The source of the labels.  Typically either label files or the output of a model
+    label_source: The source of the labels.  Typically, either label files or the output of a model
     data_dir: string defining filesystem path under which data can be found.  If None, Config().data_dir is used.
     """
 
-    # A regex for matching
+    #: (re.Pattern): A regex for matching capture file filenames
     capture_file_regex = re.compile(r"R.*harv\..*\.txt")
 
-    def __init__(self, zone:str , dt: datetime, cavity_label: str, fault_label: str, cavity_conf: float,
-                 fault_conf: float, label_source: str, data_dir:str =None):
+    def __init__(self, zone: str, dt: datetime, cavity_label: Optional[str], fault_label: Optional[str],
+                 cavity_conf: Optional[float], fault_conf: Optional[float], label_source: Optional[str],
+                 data_dir: Optional[str] =None):
         """Construct an instance of the Example class."""
 
         super().__init__(data_dir=data_dir)
 
-        # Expert/model provided labels
+        #: (str): Expert/model provided cavity label
         self.cavity_label = cavity_label
+
+        #: (str): Expert/model provided fault label
         self.fault_label = fault_label
+
+        #: (float): Cavity label confidence
         self.cavity_conf = cavity_conf
+
+        #: (float): Fault label confidence
         self.fault_conf = fault_conf
+
+        #: (str): Source of labeles (which model, file, etc.)
         self.label_source = label_source
 
-        # Zone and timestamp info for the example event
+        #: (datetime.datetime): When did the event occur
         self.event_datetime = dt
+
+        #: (str): Which zone had the event
         self.event_zone = zone
 
-        #: The type of example this is.
+        #: (ExampleType): The type of example this is.
         self.e_type = ExampleType.EXAMPLE
 
-
     def load_data(self, verbose: bool = False) -> None:
         """Top-level method for loading data associated with Example instance.
 
@@ -227,20 +245,22 @@ class Example(IExample):
         else:
             return path
 
-    def get_capture_file_contents(self) -> Dict[str, str]:
-        """Creates a dictionary of capture file content.  Typically eight files, each is ~1 MB.
+    def get_capture_file_list(self) -> List[str]:
+        """Creates a list of capture file names.  Typically, this has eight file names.
+
+        This replaced a method that reads in file contents and returned a dictionary of names to content.  The only
+        internal use case was getting the list of file names, so it was replaced with the simpler method.
 
         Returns:
-            A dictionary of capture file content keyed on the name of the capture file.
+            A list of capture file names for the Example.
         """
 
-        content = {}
+        content = []
         # Directly read each file into the dictionary
         if self.capture_files_on_disk(compressed=False):
             for filename in os.listdir(self.get_event_path(compressed=False)):
                 if Example.is_capture_file(filename):
-                    with open(os.path.join(self.get_event_path(compressed=False), filename), "r") as f:
-                        content[filename] = f.read()
+                    content.append(filename)
 
         # Wend our way through the tarfile and read the content
         elif self.capture_files_on_disk(compressed=True):
@@ -250,7 +270,7 @@ class Example(IExample):
                         # Make sure to remove the base directory from the name
                         file = os.path.basename(member.name)
                         if Example.is_capture_file(file):
-                            content[file] = f.extractfile(member)
+                            content.append(file)
 
         return content
 
@@ -358,7 +378,7 @@ class Example(IExample):
 
         # Test if we got a good status code.
         if not r.status_code == 200:
-            raise RuntimeError("Received non-ok response - " + r.status_code)
+            raise RuntimeError(f"Received non-ok response - {r.status_code}")
         if r.content == "":
             raise RuntimeError("Received empty content from  - ")
 
@@ -384,7 +404,7 @@ class Example(IExample):
             Returns:
                 bool: True if the filename appears to be a valid capture file.  Otherwise False.
         """
-        return Example.capture_file_regex.match(filename)
+        return Example.capture_file_regex.match(filename) is not None
 
     @staticmethod
     def parse_capture_file(file: str) -> pd.DataFrame:
@@ -422,27 +442,27 @@ class Example(IExample):
                     if not Example.is_capture_file(os.path.basename(member.name)):
                         continue
                     if zone_df is None:
-                        zone_df = Example.parse_capture_file(tar.extractfile(member))
+                        zone_df = Example.parse_capture_file(tar.extractfile(member)).set_index('Time')
                     else:
                         zone_df = zone_df.join(Example.parse_capture_file(tar.extractfile(member)).set_index('Time'),
-                                               on="Time")
+                                               how='outer')
         else:
             for filename in sorted(os.listdir(event_path)):
                 # Only try to process files that look like capture files
                 if not Example.is_capture_file(filename):
                     continue
                 if zone_df is None:
-                    zone_df = Example.parse_capture_file(os.path.join(event_path, filename))
+                    zone_df = Example.parse_capture_file(os.path.join(event_path, filename)).set_index('Time')
                 else:
                     # Join the existing zone data with the new capture file by using the "Time" column as an index to
                     # match rows
                     zone_df = zone_df.join(
-                        Example.parse_capture_file(os.path.join(event_path, filename)).set_index("Time"), on="Time")
+                        Example.parse_capture_file(os.path.join(event_path, filename)).set_index('Time'), how='outer')
 
         # Now format the column names to remove the zone information but keep a cavity and signal identifiers
         zone_df.columns = Example.convert_waveform_column_names(zone_df.columns)
 
-        return zone_df
+        return zone_df.reset_index()
 
     @staticmethod
     def convert_waveform_column_names(columns: List[str]) -> List[str]:
@@ -675,8 +695,9 @@ class WindowedExample(Example):
     specified time range is not a strict subset of the Examples Time column.
     """
 
-    def __init__(self, zone: str, dt: datetime, cavity_label: str, fault_label: str, cavity_conf: float,
-                 fault_conf: float, label_source: str, start: float, n_samples: int, data_dir: str = None):
+    def __init__(self, zone: str, dt: datetime, cavity_label: Optional[str], fault_label: Optional[str],
+                 cavity_conf: Optional[float], fault_conf: Optional[float], label_source: Optional[str],
+                 start: Optional[float], n_samples: int, data_dir: Optional[str] = None):
         """Construct an instance th will only store the required window upon a load_data() call.
 
         Arguments:
@@ -684,15 +705,16 @@ class WindowedExample(Example):
             n_samples: The number of samples to include after the start of the window.
         """
         super().__init__(zone, dt, cavity_label, fault_label, cavity_conf, fault_conf, label_source, data_dir)
+        #: (ExampleType): The type of Example this represents.  Convenient type tracking.
         self.e_type = ExampleType.WINDOWED_EXAMPLE
 
-        #: The start of the window relative to the fault onset
+        #: (float): The start of the window relative to the fault onset
         self.start = start
 
-        #: The number of samples requested after the start value
+        #: (int): The number of samples requested after the start value
         self.n_samples = n_samples
 
-        #: The last Time value in the window.  Determined after loading data for the first time.
+        #: (float) The last Time value in the window.  Determined after loading data for the first time.
         self.end = None
 
     def load_data(self, verbose: bool = False) -> None:
